@@ -3,7 +3,6 @@
 # 0x27 RIGHT ARROW key
 # 0x28 DOWN ARROW key
 
-
 def decrypt(file, key, path=None):
     print('Descriptografando...')
     special_ch = '!@#$%&*'
@@ -794,20 +793,28 @@ def play_sheet(notes, tempos, tom=0):
                     break
 
             if notes[id_note] < 24:
-                keyboard.press(keys[0])
+                directinput.keyDown(keys[0])
             elif notes[id_note] > 84:
-                keyboard.press(keys[-1])
+                directinput.keyDown(keys[-1])
             else:
-                keyboard.press(keys[notes[id_note]-24])
+                if '+' in keys[notes[id_note] - 24]:
+                    directinput.keyDown(keys[notes[id_note] - 24][0:keys[notes[id_note] - 24].index('+') - 1])
+                    directinput.keyDown(keys[notes[id_note] - 24][keys[notes[id_note] - 24].index('+')+2:])
+                else:
+                    directinput.keyDown(keys[notes[id_note] - 24])
 
         else:
             exec(f'note{notes[id_note]} = 0')
             if notes[id_note] < 24:
-                keyboard.release(keys[0])
+                directinput.keyUp(keys[0])
             elif notes[id_note] > 84:
-                keyboard.release(keys[-1])
+                directinput.keyUp(keys[-1])
             else:
-                keyboard.release(keys[notes[id_note] - 24])
+                if '+' in keys[notes[id_note] - 24]:
+                    directinput.keyUp(keys[notes[id_note] - 24][0:keys[notes[id_note] - 24].index('+') - 1])
+                    directinput.keyUp(keys[notes[id_note] - 24][keys[notes[id_note] - 24].index('+')+2:])
+                else:
+                    directinput.keyUp(keys[notes[id_note] - 24])
     while True:
         set = 0
         if transpose < set:
@@ -920,4 +927,10 @@ def shou_pages(type_file=None, path='.', range_list=12):
                 show_pages(songs, total_pags, '!p1', choose)
         if not choose.isnumeric():
             break
-    return choose
\ No newline at end of file
+    return choose
+
+
+def check_updates_package():
+    """check if you need to update any package and it tells you"""
+    console('pip list --outdated')
+    print('\npip install package --upgrade')
\ No newline at end of file
